@@ -1,6 +1,5 @@
 # Runtime Labels
-
-from typing import Dict
+from typing import Final
 
 from . import core, datarestore, io, math, misc, random
 from .namespace import NAMESPACE
@@ -19,10 +18,12 @@ class Labels(
     NAMESPACE = NAMESPACE
 
 
-RUNTIME_LABELS = set(getattr(Labels, x) for x in dir(Labels) if not x.startswith("__") and x != "NAMESPACE")
+RUNTIME_LABELS: Final[set[str]] = {
+    getattr(Labels, x) for x in dir(Labels) if not x.startswith("__") and x != "NAMESPACE"
+}
 
 
-def dict_join(*args: Dict[str, str]) -> Dict[str, str]:
+def _dict_join(*args: dict[str, str]) -> dict[str, str]:
     assert all(isinstance(x, dict) for x in args)
     result = {}
 
@@ -35,7 +36,7 @@ def dict_join(*args: Dict[str, str]) -> Dict[str, str]:
     return result
 
 
-LABEL_REQUIRED_MODULES = dict_join(
+LABEL_REQUIRED_MODULES: Final[dict[str, str]] = _dict_join(
     core.REQUIRED_MODULES,
     datarestore.REQUIRED_MODULES,
     math.REQUIRED_MODULES,
